# Snakemake executor plugin: irods

A plugin for handling input and output on iRODS. For usage and documentation see the [Snakemake plugin catalog](https://snakemake.github.io/snakemake-plugin-catalog/plugins/storage/irods.html).